@@ -1,19 +1,9 @@
-/******************************************************************
-  This file is a part of eco: R Package for Estimating Fitting
-  Bayesian Models of Ecological Inference for 2X2 tables
-  by Ying Lu and Kosuke Imai
-  Copyright: GPL version 2 or later.
-*******************************************************************/
-
 #include <stddef.h>
 #include <stdio.h>
 #include <math.h>
+#include <R.h>
 #include <Rmath.h>
-#include <R_ext/Utils.h>
-#include <Rinterface.h>
 #include <R_ext/PrtUtil.h>
-#include <R_ext/Memory.h>
-#include <R_ext/Random.h>
 #include "vector.h"
 #include "subroutines.h"
 #include "rand.h"
